@@ -52,7 +52,7 @@ def authorize(scope):
             
             url = f"{host}/roles/authorization"
             try:
-                response = requests.post(url, json=data, headers=headers)
+                response = requests.post(url, json=body, headers=headers)
             except:
                 return abort(make_response(jsonify({"error": f"Something went wrong while checking authorization"}), 500))
 
@@ -61,7 +61,7 @@ def authorize(scope):
                 return endpoint_func(*args, **kwargs)
 
             # if response is not 200, get the body from the response and return that
-            return abort(make_response(response.json, 403))
+            return abort(make_response(response.json(), 403))
 
         return decorated_function
     return decorator
